@@ -10,8 +10,11 @@
 #include "knewstuffcore_export.h"
 #include <QStringList>
 
+#include <memory>
+
 namespace KNSCore
 {
+class TagsFilterCheckerPrivate;
 /**
  * @brief Apply simple filtering logic to a list of tags
  *
@@ -41,6 +44,7 @@ namespace KNSCore
  * entry to be included in the return data)
  * @since 5.51
  */
+// TODO KF7: privatize this class. it's not used by the outside
 class KNEWSTUFFCORE_EXPORT TagsFilterChecker
 {
 public:
@@ -51,7 +55,7 @@ public:
      * @param tagFilter The list of tag filters
      * @since 5.51
      */
-    TagsFilterChecker(const QStringList &tagFilter);
+    explicit TagsFilterChecker(const QStringList &tagFilter);
     ~TagsFilterChecker();
 
     TagsFilterChecker(const TagsFilterChecker &) = delete;
@@ -67,8 +71,7 @@ public:
     bool filterAccepts(const QStringList &tags);
 
 private:
-    class Private;
-    Private *d;
+    const std::unique_ptr<TagsFilterCheckerPrivate> d;
 };
 
 }
